@@ -30,7 +30,7 @@ class ListVNF(tackerV10.ListCommand):
     """List VNF that belong to a given tenant."""
 
     resource = _VNF
-    list_columns = ['id', 'name', 'mgmt_url', 'status',
+    list_columns = ['id', 'name', 'mgmt_ip_address', 'status',
                     'vim_id', 'vnfd_id']
 
 
@@ -179,8 +179,23 @@ class DeleteVNF(tackerV10.DeleteCommand):
     """Delete given VNF(s)."""
 
     resource = _VNF
+    remove_output_fields = ["attributes"]
     deleted_msg = {'vnf': 'delete initiated'}
 
+    def add_known_arguments(self, parser):
+        parser.add_argument(
+            '--force',
+            default=False,
+            action='store_true',
+            help=_('Force delete VNF instance'))
+
+    def args2body(self, parsed_args):
+        body = dict()
+        if parsed_args.force:
+            body[self.resource] = dict()
+            body[self.resource]['attributes'] = {'force': True}
+        return body
+
 
 class ListVNFResources(tackerV10.ListCommand):
     """List resources of a VNF like VDU, CP, etc."""
